#!/usr/local/bin/python

"""Global constants.

Objects:

Application -- The name of the application.
Version -- The client version number.
ReleaseDate -- The date this version was released.
ServerHost -- The hostname and port number for the Assignments server.
ServerPath -- XML-RPC responder path.
ProtocolID -- Protocol version (prepended to all XML-RPC methods).
os_name -- Like os.name, but 'macosx' on MacOS X.
Service -- SASL service name.
Mechanism -- SASL mechanism the application uses.

"""

import os
import sys

Application = 'Assignments'
Version = '2.5.0-ass168.1'  # git: people/obrienjw/assignments:ass168
ReleaseDate = '2019-02-05'

os_name = os.name
# On MacOS X, find out if we are running under X11 or from an app bundle.
# This doesn't work exactly, but it should be good enough.
if sys.platform == 'darwin':
    if sys.executable.lower().find('contents/macos/python') != -1:
        os_name = 'macosx'
    else:
        os_name = 'posix'

DEFAULT_SERVER = 'assailants.net.isc.upenn.edu'
DEFAULT_PORT = '5225'
DEFAULT_PROTOCOL_ID = 'asgs2'

Server = os.environ.get('ASSIGNMENTS_SERVER', DEFAULT_SERVER)
Port = os.environ.get('ASSIGNMENTS_PORT', DEFAULT_PORT)
ServerHost = '%s:%s' % (Server, Port)
ServerPath = '/asgs'
ProtocolID = os.environ.get('ASSIGNMENTS_PROTOCOL_ID', DEFAULT_PROTOCOL_ID)
Service = 'assignments'
Mechanism = 'GSSAPI'
